<template>
    <div class="dialog-table-container sub-page-inner">
        <div class="sub-page-detail full-detail" style="width: 100%">
            <div
                class="flex-table"
                :element-loading-background="'rgba(6, 46, 106, 0.8)'"
                v-loading="loading"
            >
                <el-table
                    border
                    :data="threeResultData"
                    min-height="1000"
                    style="width: 100%"
                    :cell-style="{'text-align': 'center', color: '#fff'}"
                    :header-cell-style="{'text-align': 'center', color: '#fff'}"
                    height="100%"
                >
                    <el-table-column
                        type="index"
                        label="排名"
                        width="60"
                        align="center"
                        fixed="left"
                    >
                        <template slot-scope="scope">
                            <span>{{
                                scope.$index <= 1 ? '' : scope.$index - 1
                            }}</span>
                        </template>
                    </el-table-column>
                    <template v-for="item in tableHeader">
                        <el-table-column
                            align="center"
                            :key="item.key"
                            :label="item.label"
                            :label-class-name="
                                item.type == 'parent-column' ? 'bold' : ''
                            "
                        >
                            <el-table-column
                                align="center"
                                v-for="childrenCol in item.children"
                                :key="childrenCol.key"
                                :prop="childrenCol.key"
                                :label="childrenCol.label"
                                :min-width="childrenCol.width"
                                resizable
                                :label-class-name="
                                    childrenCol.type == 'child-type'
                                        ? 'child-bold'
                                        : 'child-normal'
                                "
                            >
                            </el-table-column>
                        </el-table-column>
                    </template>
                </el-table>
            </div>
        </div>
    </div>
</template>

<script>
import apiList from '@/api/bigScreen/majorView.js'
import utils from '@/utils.js'
const tempArr = {
    nationFirmCity: [],
    nationFirmCounty: [],
    parkAreaCity: [],
    parkAreaCounty: [],
    gEnterpriseCity: [],
    gEnterpriseCounty: [],
    nationAssetsCity: [],
    nationAssetsCounty: [],
}
export default {
    name: 'projectResultIndex',
    data() {
        return {
            tableHeader: [],
            tableHeader1: [
                {
                    label: '国企改革攻坚',
                    key: 'a',
                    type: 'parent-column',
                    children: [
                        {
                            label: '市属重点国企',
                            key: 'nationFirm-city',
                            type: 'child-type',
                            width: 160,
                        },
                        {
                            label: '利润总额增速（%）',
                            key: 'nationFirm-city-value1',
                            width: 140,
                        },
                        {
                            label: '区县',
                            key: 'nationFirm-county',
                            type: 'child-type',
                            width: 116,
                        },
                        {
                            label: '纳入目标责任书统计的\n应压减企业总户数（户）',
                            key: 'nationFirm-county-value3',
                            width: 170,
                        },
                        {
                            label: '压减户数（户）',
                            key: 'nationFirm-county-value2',
                            width: 110,
                        },
                        {
                            label: '国企法人\n压减完成率（%）',
                            key: 'nationFirm-county-value1',
                            width: 130,
                        },
                    ],
                },
            ],
            tableHeader2: [
                {
                    label: '园区开发区改革攻坚',
                    key: 'b',
                    type: 'parent-column',
                    children: [
                        {
                            label: '区县',
                            key: 'parkArea-county',
                            type: 'child-type',
                            width: 116,
                        },
                        {
                            label: '园区开发区规上工业企业亩均税收增速（%）',
                            key: 'parkArea-county-value1',
                            // width: 190,
                        },
                    ],
                },
            ],
            tableHeader3: [
                {
                    label: '政企分离改革攻坚',
                    key: 'c',
                    type: 'parent-column',
                    children: [
                        {
                            label: '市属重点国企',
                            key: 'gEnterprise-city',
                            type: 'child-type',
                            width: 160,
                        },
                        {
                            label: '国有企业（全级次）\n总量（个）',
                            key: 'gEnterprise-city-value3',
                            width: 120,
                        },
                        {
                            label: '已纳入集中统一监管\n国有企业（全级次）数量（个）',
                            key: 'gEnterprise-city-value2',
                            width: 190,
                        },
                        {
                            label: '经营性国有资产\n集中统一监管比例（%）',
                            key: 'gEnterprise-city-value1',
                            width: 160,
                        },
                        {
                            label: '区县',
                            key: 'gEnterprise-county',
                            type: 'child-type',
                            width: 116,
                        },
                        {
                            label: '国有企业（全级次）\n总量（个）',
                            key: 'gEnterprise-county-value3',
                            width: 120,
                        },
                        {
                            label: '已纳入集中统一监管\n国有企业（全级次）数量（个）',
                            key: 'gEnterprise-county-value2',
                            width: 190,
                        },
                        {
                            label: '经营性国有资产\n集中统一监管比例（%）',
                            key: 'gEnterprise-county-value1',
                            width: 160,
                        },
                    ],
                },
            ],
            tableHeader4: [
                {
                    label: '国有资产盘活',
                    key: 'd',
                    type: 'parent-column',
                    children: [
                        {
                            label: '市属重点国企',
                            key: 'nationAssets-city',
                            type: 'child-type',
                            width: 180,
                        },
                        {
                            label: '全年盘活回收\n资金目标（亿元）',
                            key: 'nationAssets-city-value3',
                            width: 140,
                        },
                        {
                            label: '已盘活回收\n资金（亿元）',
                            key: 'nationAssets-city-value2',
                            width: 130,
                        },
                        {
                            label: '存量国有资产\n盘活回收资金完成率（%）',
                            key: 'nationAssets-city-value1',
                            width: 180,
                        },
                        {
                            label: '区县',
                            key: 'nationAssets-county',
                            type: 'child-type',
                            width: 140,
                        },
                        {
                            label: '全年盘活回收\n资金目标（亿元）',
                            key: 'nationAssets-county-value3',
                            width: 140,
                        },
                        {
                            label: '已盘活回收\n资金（亿元）',
                            key: 'nationAssets-county-value2',
                            width: 130,
                        },
                        {
                            label: '存量国有资产\n盘活回收资金完成率（%）',
                            key: 'nationAssets-county-value1',
                            width: 180,
                        },
                    ],
                },
            ],
            loading: false,
            threeResultData: [],
            oneData: [],
            year: '',
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        let type = this.$route.query.type
        this.tableHeader = this[`tableHeader${type}`]
        this.$bus.$on('changeDate', (searchDate) => {
            this.getThreeResultData()
        })
    },
    created() {
        this.$emit('searchDateChange')
        this.getThreeResultData()
    },
    methods: {
        getThreeResultData() {
            this.threeResultData = []
            this.loading = true
            let {year, month} = JSON.parse(sessionStorage.getItem('searchDate'))
            this.year = year
            let data = {
                fillMonth: month,
                fillYear: year,
                indexType: '成果榜',
            }
            apiList.getThreeOneDataDetail(data, (res) => {
                if (res) {
                    this.threeResultData = this.formatData(res)
                }
                this.loading = false
            })
        },
        // 组织返回数据结构
        formatData(res) {
            let tableDataOrigin = utils.deepClone(res)
            let tempTableData = []

            for (let key in tableDataOrigin) {
                let level = this.filterTypeKey(key)
                tableDataOrigin[key].forEach((item, index) => {
                    let temp = tempTableData[index]
                    let isAdd = false
                    if (index === 0 || index === 1) {
                        isAdd = item.isAdd
                    }
                    tempTableData[index] = {
                        ...temp,
                        [level]: item.unitName,
                        [level + '-value1']: isAdd ? '-' : item.value1,
                        [level + '-value2']: isAdd ? '-' : item.value2,
                        [level + '-value3']: isAdd ? '-' : item.value3,
                    }
                })
            }
            return tempTableData
        },
        filterTypeKey(key) {
            let level = ''
            let arrKey = key.split('-')
            if (arrKey[1] == '国企改革攻坚') {
                if (arrKey[0] == '市级') {
                    level = 'nationFirm-city'
                } else if (arrKey[0] == '区县') {
                    level = 'nationFirm-county'
                }
            }
            if (arrKey[1] == '园区开发区改革攻坚') {
                if (arrKey[0] == '市级') {
                    level = 'parkArea-city'
                } else if (arrKey[0] == '区县') {
                    level = 'parkArea-county'
                }
            }
            if (arrKey[1] == '政企分离改革攻坚') {
                if (arrKey[0] == '市级') {
                    level = 'gEnterprise-city'
                } else if (arrKey[0] == '区县') {
                    level = 'gEnterprise-county'
                }
            }
            if (arrKey[1] == '国有资产盘活') {
                if (arrKey[0] == '市级') {
                    level = 'nationAssets-city'
                } else if (arrKey[0] == '区县') {
                    level = 'nationAssets-county'
                }
            }
            return level
        },
    },
}
</script>
<style lang="scss" scoped>
* {
    font-size: 18PX !important;
}

::-webkit-scrollbar {
    background-color: transparent;
}

.flex-table {
    display: flex;
    width: 100%;
    height: calc(100%);
    /deep/.el-table--border th.el-table__cell.gutter:last-of-type{
        border-bottom: none;
    }
    /deep/.el-table__fixed::before, .el-table__fixed-right::before{
        height: 0;
    }
    /deep/ thead tr th:nth-child(1){
        background-color: #072d62 !important;
    }
    /deep/.el-table__row td:nth-child(1){
        background-color: #072d62 !important;
    }

    /deep/.el-table ::-webkit-scrollbar {
        background-color: transparent;
    }

    /deep/.el-table--enable-row-hover .el-table__body tr:hover>td {
        background-color: rgb(39, 86, 162) !important;
    }

    /deep/.el-table__header-wrapper {
        .cell {
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 17PX !important;
            color: hsl(0, 0%, 100%);
            padding: 2px;
            line-height: 130%!important;
        }
    }

    /deep/.el-table__cell {
        .cell {
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 17PX !important;
            color: #fff;
            padding: 2px;
            padding:0 4px;
        }
    }
    /deep/th.el-table__cell {
        .cell {
            white-space: pre;
            line-height: 130%!important;
        }
    }

    /*最外层透明*/
    /deep/.el-table,
    /deep/.el-table__expanded-cell {
        background-color: transparent !important;
    }

    /* 表格内背景颜色 */
    /deep/.el-table th,
    /deep/.el-table tr,
    /deep/.el-table td {
        background-color: transparent !important;
    }


    /deep/.el-table--border,
    /deep/.el-table--group {
        border: 1px solid rgb(39, 86, 162) !important;
        border-right: none !important;

        &:last-child {
            border: 1px solid rgb(39, 86, 162) !important;
        }
    }
    /deep/.el-table--border {
        border: 1px solid rgb(39, 86, 162) !important;
    }

    /**
改变表格内竖线颜色
 */
    /deep/.el-table--border td,
    /deep/.el-table--border th,
    /deep/.el-table__body-wrapper .el-table--border.is-scrolling-left~.el-table__fixed {
        border-right: 1px solid rgb(39, 86, 162) !important;

        &:last-child {
            border-right: none !important;
        }
    }

    /**
改变表格内行线颜色
 */
    /deep/.el-table td,
    /deep/.el-table th.is-leaf {
        border-bottom: 1px solid rgb(39, 86, 162) !important;
    }

    /deep/.el-table thead tr th {
        border-color: rgb(39, 86, 162);
    }

    /deep/.el-table--border::after {
        background: none;
    }

    /deep/.el-table::before {
        height: 0px;
    }

    /deep/.el-table--scrollable-y .el-table__body-wrapper {
        overflow-y: auto;
    }
}
</style>
<style lang="scss">
@import './table.scss';
</style>
